importComments abstract method
Imports comments from a list of serialised maps (the inverse of exportComments). Replaces any existing comments.
Implementation
void importComments(List<Map<String, dynamic>> data);
Imports comments from a list of serialised maps (the inverse of exportComments). Replaces any existing comments.
void importComments(List<Map<String, dynamic>> data);