FNode class

Implementers
Annotations
  • @JsonSerializable.new()

Constructors

FNode(String id)
FNode.fromJson(Map<String, dynamic> json)
factory

Properties

contentVersion → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bumpVersion() → void
Increment the version so the delta system knows this node changed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited