bumpVersion method
void
bumpVersion()
Increment the version so the delta system knows this node changed.
Implementation
void bumpVersion() => _contentVersion++;
Increment the version so the delta system knows this node changed.
void bumpVersion() => _contentVersion++;