FluentRow class

Inheritance
Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

FluentRow({List<FluentCell>? cells, double? rowHeight})
FluentRow.fromJson(Map<String, dynamic> json)
factory

Properties

cells List<FluentCell>
getter/setter pair
contentVersion int
no setterinherited
fragments List<FNode>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
rowHeight double?
Explicit height of the row (in logical pixels). If null, calculated automatically based on content.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setteroverride
type String
no setter

Methods

bumpVersion() → void
Increment the version so the delta system knows this node changed.
inherited
getChildren() List<FluentCell>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited