FluentTable class

Inheritance
Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

FluentTable({List<FluentRow>? rows, List<double>? columnWidths, double? tableWidth})
FluentTable.fromJson(Map<String, dynamic> json)
factory

Properties

columnWidths List<double>?
Explicit widths for each column (in logical pixels). If null or length different from number of columns, it is ignored and calculated uniformly by the renderer.
getter/setter pair
contentVersion int
no setterinherited
fragments List<FNode>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
rows List<FluentRow>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableWidth double?
Total width of the table (in logical pixels). If null, occupies all available width.
getter/setter pair
text String
no setteroverride
type String
no setter

Methods

bumpVersion() → void
Increment the version so the delta system knows this node changed.
inherited
getChildren() List<FluentRow>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited