HorizontalRule class
Atomic node representing a horizontal line (
). Extends Fragment (like FluentImage) to participate in the selection and copy/paste system. Has 2 caret stops (offset 0 and 1), no children.
- Inheritance
- Implemented types
Constructors
- HorizontalRule()
-
HorizontalRule.fromJson(Map<
String, dynamic> json) -
factory
Properties
- color ↔ String?
-
Text color in hex format (e.g. '#FF0000'). Null = auto (default color).
getter/setter pairinherited
- contentVersion → int
-
no setterinherited
- fontFamily ↔ String
-
Font family for this fragment (e.g. 'DejaVu Sans', 'Roboto').
getter/setter pairinherited
- fontSize ↔ double
-
Font size in points (e.g. 14.0).
getter/setter pairinherited
-
fragments
→ List<
FNode> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor ↔ String?
-
Highlight color (background) in hex format. Null = no highlight.
getter/setter pairinherited
- id ↔ String
-
getter/setter pairinherited
- isBold → bool
-
no setterinherited
- renderText → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
↔ List<
String> ? -
List of applied inline styles, e.g.
'bold','italic','bold','italic'.getter/setter pairinherited - text ↔ String
-
getter/setter pairinherited-setteroverride-getter
- type ↔ String
-
getter/setter pairinherited-setteroverride-getter
Methods
-
bumpVersion(
) → void -
Increment the version so the delta system knows this node changed.
inherited
-
getChildren(
) → List< FNode> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited