ListItem class

ListItem as a generic container for list elements. Can contain paragraphs, images, tables, etc. as children.

Inheritance
Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

ListItem({required String bulletType, required List<int> indexList, List<FNode>? children})
ListItem.fromJson(Map<String, dynamic> json)
factory

Properties

bulletType String
getter/setter pair
children List<FNode>
getter/setter pair
contentVersion int
no setterinherited
fragments List<FNode>
Compatibility getter: aggregates all Fragments from Paragraph children
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
indexList List<int>
getter/setter pair
renderText String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Compatibility getter: returns concatenated text from Paragraph children
getter/setter pairoverride-getter
type String
no setter

Methods

bumpVersion() → void
Increment the version so the delta system knows this node changed.
inherited
getChildren() List<FNode>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited