styleName property
Style applied to the paragraph (e.g. "normal", "heading1"). If null, uses the explicit properties of the paragraph.
Implementation
String? styleName;
Style applied to the paragraph (e.g. "normal", "heading1"). If null, uses the explicit properties of the paragraph.
String? styleName;