Root class
- Inheritance
- Implemented types
- Annotations
-
- @JsonSerializable.new()
Properties
- contentVersion → int
-
no setterinherited
-
fragments
→ List<
FNode> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pairinherited
-
nodes
↔ List<
FNode> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
no setteroverride
- type ↔ String
-
getter/setter pair
Methods
-
bumpVersion(
) → void -
Increment the version so the delta system knows this node changed.
inherited
-
getChildren(
) → List< FNode> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited