cursorOnlyChange property

bool get cursorOnlyChange

True while listeners are being notified for a cursor-only change. Widgets that do expensive work on every document change can check this flag and skip irrelevant updates (e.g. toolbar style scan, full tree rebuild) when the document text / structure did not change.

Implementation

bool get cursorOnlyChange => _cursorOnlyChange;