editorFocusNode property
FocusNode for the editing area. The toolbar can request focus after an interaction (e.g., font selection) by calling requestEditorFocus.
Implementation
final FocusNode editorFocusNode = FocusNode();
FocusNode for the editing area. The toolbar can request focus after an interaction (e.g., font selection) by calling requestEditorFocus.
final FocusNode editorFocusNode = FocusNode();