pendingFontFamily property
Active font family for collapsed cursor (persistent like Word). When the user types, new text inherits this font.
Implementation
String pendingFontFamily = 'DejaVu Sans';
Active font family for collapsed cursor (persistent like Word). When the user types, new text inherits this font.
String pendingFontFamily = 'DejaVu Sans';