spellCheckProvider property
Optional spell-check plugin. When set, the editor will use it for underlining misspelled words and providing suggestions.
Implementation
SpellCheckProvider? spellCheckProvider;
Optional spell-check plugin. When set, the editor will use it for underlining misspelled words and providing suggestions.
SpellCheckProvider? spellCheckProvider;