EventHandler class

Constructors

EventHandler()

Properties

document FluentDocument
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isCtrlPressed bool
getter/setter pair
isMetaPressed bool
getter/setter pair
isShiftPressed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(dynamic event, FluentDocument document) → void
handleArrowKeys(KeyEvent event) bool
handleBackspaceKey(KeyEvent event) bool
handleBold() bool
handleCharacterInput(KeyEvent event) bool
handleClearFormatting() bool
handleDeleteKey(KeyEvent event) bool
handleEndKey(KeyEvent event) bool
handleEnterKey(KeyEvent event) bool
handleFontFamily(String fontFamily) bool
handleFontSize(double fontSize) bool
handleHighlightColor(String? color) bool
handleHomeKey(KeyEvent event) bool
handleInsertImage(BuildContext context) → void
Shows the dialog to insert an image and inserts it if confirmed.
Shows the dialog to insert a link and inserts it if confirmed.
handleInsertNode(String nodeType, [Map<String, dynamic>? options]) → void
handleItalic() bool
handleKeyDown(KeyEvent event, FluentDocument document) → void
handleMetaActions(KeyEvent event) bool
handlePageDownKey(KeyEvent event) bool
handlePageUpKey(KeyEvent event) bool
handleParagraphSpacing({double? lineHeight, double? spacingBefore, double? spacingAfter}) bool
handleParagraphStyle(ParagraphStyle style) bool
Applies a paragraph style to the current paragraph or selection.
handleShiftTab() bool
handleSmallCaps() bool
handleStrikethrough() bool
handleSubscript() bool
handleSuperscript() bool
handleTab() bool
handleTabKey(KeyEvent event) bool
handleTextAlign(String align) bool
handleTextColor(String? color) bool
handleUnderline() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTapWithPosition(Offset localPosition, RenderBox renderBox, Widget widget) → void
onTapDown(TapDownDetails details, BuildContext context, Widget widget) → void
onTapDownWithPosition(Offset localPosition, RenderBox renderBox, Widget widget) → void
onTripleTapWithPosition(Offset localPosition, RenderBox renderBox, Widget widget) → void
toString() String
A string representation of this object.
inherited
updateModifiers(KeyEvent event) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited