handlers/handle_highlight_color library

Functions

executeHandleHighlightColor(FluentDocument document, String? color) bool
Applies highlight color to fragments affected by the selection or stores the pending color for collapsed cursor. Pass null or empty string to remove the highlight.