handlers/handle_text_color library

Functions

executeHandleTextColor(FluentDocument document, String? color) bool
Applies text color to fragments affected by the selection or stores the pending color for collapsed cursor. Pass null or empty string for "auto" (removes the color).