ImeConnectionManager class

Constructors

ImeConnectionManager(TextInputClient client)

Properties

client TextInputClient
final
connection TextInputConnection?
getter/setter pair
connectionRetryCount int
getter/setter pair
connectionRetryTimer Timer?
getter/setter pair
document FluentDocument?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isConnectionActive bool
no setter
lastCaretRect Rect?
getter/setter pair
lastViewSize Size?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachConnection({required int viewId, required VoidCallback onSyncBuffer}) bool
attachInput(FluentDocument doc) → void
detachInput() → void
hideKeyboard() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setViewSize(Size size) → void
showKeyboard(BuildContext context, {required VoidCallback onSyncBuffer}) → void
toString() String
A string representation of this object.
inherited
updateCaretRect(Rect rect) → void
updateWebImePosition() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxConnectionRetries → const int
windowsRetryDelays → const List<Duration>