ImeTextUtils class

Constructors

ImeTextUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

commonPrefixLength(String a, String b) int
computeInsertedText(String oldText, String newText) String
findDiffIndex(String a, String b) int
findWordEndOffset(String text, int offset) int
findWordStartOffset(String text, int offset) int
isWordBoundary(String char) bool
sanitizeUtf16(String s) String
snapCursorOffset(String text, int offset) int