FluentEditorLabels class
Localization system for FluentEditor.
To make the editor multilingual, pass an instance of this class
to the FluentEditor widget via the labels parameter.
Example:
FluentEditor(
labels: FluentEditorLabels(
file: 'File',
edit: 'Edit',
insert: 'Insert',
format: 'Format',
// ... other translations
),
)
Constructors
- FluentEditorLabels({String file = 'File', String save = 'Save (.fluent)', String open = 'Open (.fluent)', String exportAs = 'Export as...', String microsoftWord = 'Microsoft Word (.docx)', String libreOffice = 'LibreOffice (.odt)', String pdf = 'PDF (.pdf)', String html = 'HTML (.html)', String markdown = 'Markdown (.md)', String importHtml = 'Import HTML (.html)', String importMarkdown = 'Import Markdown (.md)', String importDocx = 'Import Word (.docx)', String importOdt = 'Import ODT (.odt)', String fileSaved = 'File saved', String fileLoaded = 'File loaded successfully', String fileLoadError = 'Error loading file', String exportSuccess = 'Exported', String exportError = 'Error exporting', String documentCopied = 'Document copied as JSON', String edit = 'Edit', String undo = 'Undo', String redo = 'Redo', String cut = 'Cut', String copy = 'Copy', String paste = 'Paste', String pasteWithoutFormatting = 'Paste without formatting', String selectAll = 'Select all', String delete = 'Delete', String wordCount = 'Word count', String insert = 'Insert', String link = 'Link', String image = 'Image', String table = 'Table', String horizontalLine = 'Horizontal line', String settings = 'Settings', String showStats = 'Show stats', String documentLanguage = 'Document Language', String format = 'Format', String text = 'Text', String bold = 'Bold', String italic = 'Italic', String underline = 'Underline', String strikethrough = 'Strikethrough', String superscript = 'Superscript', String subscript = 'Subscript', String smallCaps = 'Small caps', String styles = 'Styles', String align = 'Align and indent', String alignLeft = 'Align left', String alignCenter = 'Align center', String alignRight = 'Align right', String justify = 'Justify', String increaseIndent = 'Increase indent', String decreaseIndent = 'Decrease indent', String alignAndIndent = 'Align and indent', String lineSpacing = 'Line and paragraph spacing', String lineSpacingSingle = 'Single', String lineSpacing115 = '1.15', String lineSpacing15 = '1.5', String lineSpacingDouble = 'Double', String paragraphSpacing = 'Paragraph Spacing', String textColor = 'Text color', String highlightColor = 'Highlight', String insertLink = 'Insert Link', String cancel = 'Cancel', String confirmButton = 'Confirm', String insertButton = 'Insert', String apply = 'Apply', String insertImage = 'Insert image', String or = 'or', String done = 'Done', String url = 'URL', String urlHint = 'https://example.com', String urlRequired = 'Please enter a URL', String linkText = 'Text', String linkTextHint = 'Link text', String linkTextRequired = 'Please enter link text', String lineHeight = 'Line height', String spacingBefore = 'Spacing before', String spacingAfter = 'Spacing after', String imageUrl = 'Image URL', String imageUrlHint = 'https://example.com/image.png', String dragImageHere = 'Drag an image here or click to choose', String clickToChooseImage = 'Click to choose an image', String imageSelected = 'Image selected', String fileReadError = 'Error reading file', String chooseListMarkerType = 'Choose List Marker Type', String all = 'All', String bullets = 'Bullets', String numbers = 'Numbers', String checkboxes = 'Checkboxes', String replaceImage = 'Replace image', String replaceLink = 'Replace link', String deleteImage = 'Delete', String deleteLink = 'Delete', String goToLink = 'Go to link', String insertRowAbove = 'Insert row above', String insertRowBelow = 'Insert row below', String addCommentLabel = 'Add comment', String commentDialogTitle = 'Add comment', String commentHint = 'Write a comment...', String commentOverlapWarning = 'Warning: the comment overlaps an existing comment.', String sidebarTitle = 'Comments', String showResolvedLabel = 'Show resolved', String showCommentsLabel = 'Show comments', String hideCommentsLabel = 'Hide comments', String deletedTextLabel = 'Text deleted', String resolvedLabel = 'Resolved', String replyHint = 'Reply...', String resolveButton = 'Resolve', String defaultAuthorName = 'User', String anonymousLabel = 'Anonymous', String pdfCommentSubject = 'Comment', String authorInfoDialogTitle = 'Author Information', String authorNameLabel = 'Author Name', String authorNameHint = 'Enter your name...', String setAuthorLabel = 'Set author'})
-
Constructor with default values in English
const
Properties
- addCommentLabel → String
-
final
- align → String
-
final
- alignAndIndent → String
-
final
- alignCenter → String
-
final
- alignLeft → String
-
final
- alignRight → String
-
final
- all → String
-
final
- anonymousLabel → String
-
final
- apply → String
-
final
-
final
-
final
-
final
- bold → String
-
final
- bullets → String
-
final
- cancel → String
-
final
- checkboxes → String
-
final
- chooseListMarkerType → String
-
final
- clickToChooseImage → String
-
final
- commentDialogTitle → String
-
final
- commentHint → String
-
final
- commentOverlapWarning → String
-
final
- confirmButton → String
-
final
- copy → String
-
final
- cut → String
-
final
- decreaseIndent → String
-
final
- defaultAuthorName → String
-
final
- delete → String
-
final
- deletedTextLabel → String
-
final
- deleteImage → String
-
final
- deleteLink → String
-
final
- documentCopied → String
-
final
- documentLanguage → String
-
final
- done → String
-
final
- dragImageHere → String
-
final
- edit → String
-
Menu Edit
final
- exportAs → String
-
final
- exportError → String
-
final
- exportSuccess → String
-
final
- file → String
-
Menu File
final
- fileLoaded → String
-
final
- fileLoadError → String
-
final
- fileReadError → String
-
final
- fileSaved → String
-
final
- format → String
-
Menu Format
final
- goToLink → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideCommentsLabel → String
-
final
- highlightColor → String
-
final
- horizontalLine → String
-
final
- html → String
-
final
- image → String
-
final
- imageSelected → String
-
final
- imageUrl → String
-
final
- imageUrlHint → String
-
final
- importDocx → String
-
final
- importHtml → String
-
final
- importMarkdown → String
-
final
- importOdt → String
-
final
- increaseIndent → String
-
final
- insert → String
-
Menu Insert
final
- insertButton → String
-
final
- insertImage → String
-
final
- insertLink → String
-
Dialogs
final
- insertRowAbove → String
-
final
- insertRowBelow → String
-
final
- italic → String
-
final
- justify → String
-
final
- libreOffice → String
-
final
- lineHeight → String
-
final
- lineSpacing → String
-
final
- lineSpacing115 → String
-
final
- lineSpacing15 → String
-
final
- lineSpacingDouble → String
-
final
- lineSpacingSingle → String
-
final
- link → String
-
final
- linkText → String
-
final
- linkTextHint → String
-
final
- linkTextRequired → String
-
final
- markdown → String
-
final
- microsoftWord → String
-
final
- numbers → String
-
final
- open → String
-
final
- or → String
-
final
- paragraphSpacing → String
-
final
- paste → String
-
final
- pasteWithoutFormatting → String
-
final
- pdf → String
-
final
- pdfCommentSubject → String
-
final
- redo → String
-
final
- replaceImage → String
-
final
- replaceLink → String
-
final
- replyHint → String
-
final
- resolveButton → String
-
final
- resolvedLabel → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- save → String
-
final
- selectAll → String
-
final
- setAuthorLabel → String
-
final
- settings → String
-
Menu Settings
final
- showCommentsLabel → String
-
final
- showResolvedLabel → String
-
final
- showStats → String
-
final
-
final
- smallCaps → String
-
final
- spacingAfter → String
-
final
- spacingBefore → String
-
final
- strikethrough → String
-
final
- styles → String
-
final
- subscript → String
-
final
- superscript → String
-
final
- table → String
-
final
- text → String
-
final
- textColor → String
-
final
- underline → String
-
final
- undo → String
-
final
- url → String
-
final
- urlHint → String
-
final
- urlRequired → String
-
final
- wordCount → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited