DocumentLanguage class
Model for a document language.
Constructors
- DocumentLanguage({required String code, required String name, required String flag})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
String code) → DocumentLanguage
Constants
- englishUK → const DocumentLanguage
- englishUS → const DocumentLanguage
- french → const DocumentLanguage
- german → const DocumentLanguage
- italian → const DocumentLanguage
- spanish → const DocumentLanguage
-
supported
→ const List<
DocumentLanguage>