FluentBuiltInPlugin class

Inheritance

Constructors

FluentBuiltInPlugin()

Properties

apiVersion int
no setterinherited
commands List<FluentCommand>
no setterinherited
dependencies List<FluentPluginDependency>
no setterinherited
formats List<FluentFormatContribution>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasSidebar bool
Returns true if this plugin contributes to the document sidebar.
no setterinherited
id String
no setteroverride
isSuggestionMode bool
Returns true if this plugin is currently operating in suggestion/review mode.
no setterinherited
nodes List<FluentNodeDefinition<FNode>>
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleHook RenderStyleHook?
no setterinherited
ui List<FluentUiContribution>
no setterinherited
version String
no setteroverride

Methods

attach(FluentPluginContext context) → void
inherited
buildSidebarItems(BuildContext context, FluentDocument document) List<FluentSidebarItem>
Returns sidebar item entries (cards) contributed by this plugin. Libraries define how their cards appear by returning FluentSidebarItems.
inherited
detach(FluentPluginContext context) → void
inherited
isColumnResized(FluentDocument document, FluentTable table, int colIdx) bool
Returns true if the column at colIdx in table has a pending resize suggestion.
inherited
isFormattingDisabled(FluentDocument document) bool
Returns true if style formatting actions (bold, italic, color, font size, etc.) should be disabled on document.
inherited
isRowResized(FluentDocument document, FluentTable table, FluentRow row) bool
Returns true if the row row in table has a pending resize suggestion.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBackspace(FluentDocument document, {bool ctrl = false, bool lineStart = false}) bool
Intercepts Backspace key. Return true if handled.
inherited
onColumnResize(FluentDocument document, FluentTable table, int colIdx, double oldWidth, double newWidth) bool
Called when a table column is resized. Return true if handled.
inherited
onCommitSaveState(FluentDocument document, {SaveStateResult result = SaveStateResult.created}) → void
Called when a saveState operation is committed for the document.
inherited
onDecreaseTableColspan(FluentDocument document, FluentTable table, FluentCell cell) bool
Intercepts decreasing table cell colspan. Return true if handled.
inherited
onDecreaseTableRowspan(FluentDocument document, FluentTable table, FluentCell cell) bool
Intercepts decreasing table cell rowspan. Return true if handled.
inherited
onDelete(FluentDocument document, {bool ctrl = false}) bool
Intercepts Delete key. Return true if handled.
inherited
onDeleteNode(FluentDocument document, FNode node) bool
Intercepts deleting a node (e.g. image, HR, table). Return true if handled.
inherited
onDeleteTableColumn(FluentDocument document, FluentTable table, int index) bool
Intercepts deleting a table column. Return true if handled.
inherited
onDeleteTableRow(FluentDocument document, FluentTable table, int index) bool
Intercepts deleting a table row. Return true if handled.
inherited
onEnter(FluentDocument document) bool
Intercepts Enter key (line/item split). Return true if handled.
inherited
onImeCompositionCommit(String text, FluentDocument document) bool
Intercepts committing IME composition/preedit text. Return true if handled.
inherited
onIncreaseTableColspan(FluentDocument document, FluentTable table, FluentCell cell) bool
Intercepts increasing table cell colspan. Return true if handled.
inherited
onIncreaseTableRowspan(FluentDocument document, FluentTable table, FluentCell cell) bool
Intercepts increasing table cell rowspan. Return true if handled.
inherited
onInsertCharacter(String character, FluentDocument document) bool
Intercepts character insertion. Return true if handled.
inherited
onInsertNode(FluentDocument document, String nodeType, Map<String, dynamic> options) bool
Intercepts inserting a node (e.g. hr, image, list, table). Return true if handled.
inherited
onInsertTableColumn(FluentDocument document, FluentTable table, int index) bool
Intercepts inserting a table column. Return true if handled.
inherited
onInsertTableRow(FluentDocument document, FluentTable table, int index) bool
Intercepts inserting a table row. Return true if handled.
inherited
onInsertText(String text, FluentDocument document) bool
Intercepts inserting text (single character or multi-character string from IME/paste). Return true if handled.
inherited
onLeavesStyleMutation(FluentDocument document, List<Fragment> leaves, void mutator(Fragment)) List<Fragment>?
Intercepts an inline style mutation on a list of fragments. Return the modified/new fragments if handled, null otherwise.
inherited
onParagraphMutation(FluentDocument document, Paragraph paragraph, void mutator(Paragraph)) bool
Intercepts a paragraph mutation. Return true if handled, false otherwise.
inherited
onRedo(FluentDocument document) → void
Called after a redo operation restores the document state.
inherited
onReplaceSelection(String character, FluentDocument document) bool
Intercepts replacing active selection with text. Return true if handled.
inherited
onRowResize(FluentDocument document, FluentTable table, FluentRow row, double oldHeight, double newHeight) bool
Called when a table row is resized. Return true if handled.
inherited
onSaveState(FluentDocument document, String description) → void
Called when a saveState operation begins for the document.
inherited
onStyleMutation(FluentDocument document, Fragment leaf, void mutator(Fragment)) Fragment?
Intercepts an inline style mutation on a fragment. Return the modified/new fragment if handled, null otherwise.
inherited
onTab(FluentDocument document, {required bool isShiftPressed}) bool
Intercepts Tab/Shift+Tab keys (indent/outdent). Return true if handled.
inherited
onTextMutation(String paragraphId, int fromOffset, int delta) → void
Called whenever document text is mutated.
inherited
onUndo(FluentDocument document) → void
Called after an undo operation restores the document state.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited