FluentCommand class

Constructors

FluentCommand({required String id, required String label, required FluentCommandCallback execute, FluentCommandPredicate? canExecute, List<FluentKeyBinding> keyBindings = const [], String? undoDescription, bool forceNewUndoAction = false})
const

Properties

canExecute FluentCommandPredicate?
final
execute FluentCommandCallback
final
forceNewUndoAction bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
keyBindings List<FluentKeyBinding>
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
undoDescription String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited