hasSidebar property
bool
get
hasSidebar
Returns true if this plugin contributes to the document sidebar.
Implementation
bool get hasSidebar => false;
Returns true if this plugin contributes to the document sidebar.
bool get hasSidebar => false;