isRowResized method
Returns true if the row row in table has a pending resize suggestion.
Implementation
bool isRowResized(FluentDocument document, FluentTable table, FluentRow row) => false;
Returns true if the row row in table has a pending resize suggestion.
bool isRowResized(FluentDocument document, FluentTable table, FluentRow row) => false;