FluentFormatContribution class

Constructors

FluentFormatContribution({required String id, required String label, required List<String> extensions, List<String> mimeTypes = const [], FluentPluginFormatKind kind = FluentPluginFormatKind.text, FutureOr<Root> import(FluentImportPayload payload, FluentPluginRegistry registry)?, FutureOr<FluentExportPayload> export(FluentDocument document)?})
const

Properties

export FutureOr<FluentExportPayload> Function(FluentDocument document)?
final
extensions List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
import FutureOr<Root> Function(FluentImportPayload payload, FluentPluginRegistry registry)?
final
kind FluentPluginFormatKind
final
label String
final
mimeTypes List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited