FluentKeyBinding class
Constructors
- FluentKeyBinding({required LogicalKeyboardKey key, bool control = false, bool meta = false, bool shift = false, bool alt = false, int priority = 0})
-
const
Properties
- alt → bool
-
final
- control → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → LogicalKeyboardKey
-
final
- meta → bool
-
final
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shift → bool
-
final
- signature → String
-
no setter
Methods
-
matches(
KeyEvent event, HardwareKeyboard keyboard) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited