FluentNodeDefinition<T extends FNode> class

Constructors

FluentNodeDefinition({required String type, required Type nodeClass, required FluentNodeDecoder decode, required FluentNodeFactory create, required FluentNodeWidgetBuilder buildWidget, List<FNode> children(T node) = _noChildren, List<FNode>? mutableChildren(T node) = _noMutableChildren, bool inline = false, bool atomic = false, Map<String, Object? Function(T node)> formatProjections = const {}})
const

Properties

atomic bool
final
buildWidget FluentNodeWidgetBuilder
final
children List<FNode> Function(T node)
final
create FluentNodeFactory
final
decode FluentNodeDecoder
final
formatProjections Map<String, Object? Function(T node)>
final
hashCode int
The hash code for this object.
no setterinherited
inline bool
final
mutableChildren List<FNode>? Function(T node)
final
nodeClass Type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited