FluentPluginRegistry class

Properties

commands Iterable<FluentCommand>
no setter
formats Iterable<FluentFormatContribution>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasSidebarPlugins bool
Returns true if any registered plugin supports sidebar items.
no setter
isSuggestionMode bool
Returns true if any registered plugin is currently in suggestion/review mode.
no setter
plugins List<FluentEditorPlugin>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleHooks List<RenderStyleHook>
no setter

Methods

attach(FluentDocument document) → void
buildSidebarItems(BuildContext context, FluentDocument document) List<FluentSidebarItem>
Collects all sidebar items contributed across registered plugins.
command(String id) FluentCommand?
createNode(String type, [Map<String, dynamic> options = const {}]) FNode
decodeNode(Map<String, dynamic> json) FNode
detach(FluentDocument document) → void
dispatchBackspace(FluentDocument document, {bool ctrl = false, bool lineStart = false}) bool
dispatchColumnResize(FluentDocument document, FluentTable table, int colIdx, double oldWidth, double newWidth) bool
dispatchCommitSaveState(FluentDocument document, {SaveStateResult result = SaveStateResult.created}) → void
dispatchDelete(FluentDocument document, {bool ctrl = false}) bool
dispatchDeleteNode(FluentDocument document, FNode node) bool
dispatchEnter(FluentDocument document) bool
dispatchImeCompositionCommit(String text, FluentDocument document) bool
dispatchInsertCharacter(String character, FluentDocument document) bool
dispatchInsertNode(FluentDocument document, String nodeType, Map<String, dynamic> options) bool
dispatchInsertText(String text, FluentDocument document) bool
dispatchKeyEvent(KeyEvent event, FluentDocument document, {BuildContext? buildContext}) bool
dispatchLeavesStyleMutation(FluentDocument document, List<Fragment> leaves, void mutator(Fragment)) List<Fragment>?
dispatchParagraphMutation(FluentDocument document, Paragraph paragraph, void mutator(Paragraph)) bool
dispatchRedo(FluentDocument document) → void
dispatchReplaceSelection(String character, FluentDocument document) bool
dispatchRowResize(FluentDocument document, FluentTable table, FluentRow row, double oldHeight, double newHeight) bool
dispatchSaveState(FluentDocument document, String description) → void
dispatchStyleMutation(FluentDocument document, Fragment leaf, void mutator(Fragment)) Fragment?
dispatchTab(FluentDocument document, {required bool isShiftPressed}) bool
dispatchTextMutation(String paragraphId, int fromOffset, int delta) → void
dispatchUndo(FluentDocument document) → void
executeCommand(String id, FluentDocument document, {BuildContext? buildContext}) bool
format(String id) FluentFormatContribution?
formatForExtension(String ext) FluentFormatContribution?
isColumnResized(FluentDocument document, FluentTable table, int colIdx) bool
isFormattingDisabled(FluentDocument document) bool
Returns true if any registered plugin requires formatting/style actions to be disabled.
isRowResized(FluentDocument document, FluentTable table, FluentRow row) bool
nodeFor(FNode node) FluentNodeDefinition<FNode>?
nodeForType(String type) FluentNodeDefinition<FNode>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uiAt(FluentPluginUiLocation location) Iterable<FluentUiContribution>

Operators

operator ==(Object other) bool
The equality operator.
inherited