hasSidebarPlugins property
bool
get
hasSidebarPlugins
Returns true if any registered plugin supports sidebar items.
Implementation
bool get hasSidebarPlugins => plugins.any((p) => p.hasSidebar);
Returns true if any registered plugin supports sidebar items.
bool get hasSidebarPlugins => plugins.any((p) => p.hasSidebar);