FluentUiContribution class

Constructors

FluentUiContribution({required String id, required FluentPluginUiLocation location, required Widget builder(BuildContext context, FluentDocument document), int order = 0, bool visible(FluentDocument document)?})
const

Properties

builder Widget Function(BuildContext context, FluentDocument document)
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
location FluentPluginUiLocation
final
order int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool Function(FluentDocument document)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited