isWrapped property
bool
get
isWrapped
Returns true if the text was wrapped on multiple lines
Implementation
bool get isWrapped {
return size.height > _painter.preferredLineHeight * 1.5;
}
Returns true if the text was wrapped on multiple lines
bool get isWrapped {
return size.height > _painter.preferredLineHeight * 1.5;
}