DocxExporter class

Generates a native DOCX (OOXML) file from the document.

Constructors

DocxExporter(FluentDocument document, {Map<String, Uint8List>? imageCache})

Properties

document FluentDocument
final
hashCode int
The hash code for this object.
no setterinherited
imageCache Map<String, Uint8List>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited