ExportService class

Constructors

ExportService(FluentDocument document)

Properties

document FluentDocument
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportToDocx() Future<Uint8List>
Exports as native DOCX (OOXML) file.
exportToHtml() Future<String>
exportToMarkdown() String
exportToOdt() Future<Uint8List>
Exports as native ODT (OpenDocument) file.
exportToPdf() Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveFileNative(Uint8List bytes, String defaultName, String extension) Future<String?>
saveTextFileNative(String content, String defaultName, String extension) Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited