ImportService class
Facade for importing content from various formats into a FluentEditor Root.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
importFromDocx(
List< int> bytes) → Root -
importFromHtml(
String html) → Root -
importFromMarkdown(
String md) → Root -
importFromOdt(
List< int> bytes) → Root -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited