OdtExporter class

Generates a native ODT (OpenDocument Text) file from the document.

An ODT is a ZIP archive containing:

  • mimetype (uncompressed, first entry)
  • META-INF/manifest.xml
  • content.xml (content + automatic styles)
  • styles.xml
  • Pictures/ (embedded images)

Constructors

OdtExporter(FluentDocument document, {Map<String, Uint8List>? imageCache})

Properties

document FluentDocument
final
hashCode int
The hash code for this object.
no setterinherited
imageCache Map<String, Uint8List>
Cache of external images already downloaded (src -> bytes).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<Uint8List>
Generates the ODT file bytes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited