CursorSnapshot class

Cursor / selection state captured at the time of the delta.

Constructors

CursorSnapshot({required String anchorId, required int anchorOffset, String? focusId, int? focusOffset})
const
CursorSnapshot.fromDocument(FluentDocument document)
factory

Properties

anchorId String
final
anchorOffset int
final
focusId String?
final
focusOffset int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(FluentDocument document) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited