NodeChange class

A single changed node: old JSON → new JSON at a specific index.

Constructors

NodeChange({required int index, required Map<String, dynamic> oldJson, required Map<String, dynamic> newJson})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
newJson Map<String, dynamic>
final
oldJson Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited