NodeInsertDelta class

Inserts a new top-level node at a given index.

Inheritance

Constructors

NodeInsertDelta({required String description, required DateTime timestamp, required int index, required Map<String, dynamic> nodeJson, required CursorSnapshot oldCursor, required CursorSnapshot newCursor})
const

Properties

description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
index int
final
newCursor CursorSnapshot
final
nodeJson Map<String, dynamic>
final
oldCursor CursorSnapshot
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
finalinherited

Methods

apply(FluentDocument document) → void
Apply this delta (redo). Replaces affected nodes with their post-mutation state and restores the post-mutation cursor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert(FluentDocument document) → void
Revert this delta (undo). Replaces affected nodes with their pre-mutation state and restores the pre-mutation cursor.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited