SaveStateResult enum

Result of committing a document saveState operation.

Inheritance
Available extensions

Values

created → const SaveStateResult

A new delta was created and pushed to the undo stack.

merged → const SaveStateResult

The changes were merged into the previous delta on the undo stack.

noChange → const SaveStateResult

No changes were detected; no delta was created or merged.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SaveStateResult>
A constant List of the values in this enum, in order of their declaration.