CaretStop class

A position reachable by the cursor in the document.

Constructors

CaretStop(String fragmentId, int offset)
const

Properties

fragmentId String
final
hashCode int
The hash code for this object.
no setteroverride
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override