LogicalLine class

Represents a "logical line" of the document.

Constructors

LogicalLine({required InlineContainerNode node, required List<CaretStop> stops})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
node InlineContainerNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stops List<CaretStop>
final

Methods

indexOf(CaretStop stop) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited