NavigationResult class

Result of a cursor movement. position is the new position (null = no movement possible). preferredX is the x coordinate to preserve for subsequent Up/Down.

  • Left/Right: always ignored by the caller (reset to -1.0).
  • Up/Down: preserved unchanged during vertical sequences.

Constructors

const

Properties

hashCode int
The hash code for this object.
no setterinherited
position CaretStop?
final
preferredX double
X coordinate in logical pixels to preserve for the next Up/Down. Equals 0.0 for Left/Right results (the caller ignores it).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const NavigationResult