preferredX property
X coordinate in logical pixels to preserve for the next Up/Down. Equals 0.0 for Left/Right results (the caller ignores it).
Implementation
final double preferredX;
X coordinate in logical pixels to preserve for the next Up/Down. Equals 0.0 for Left/Right results (the caller ignores it).
final double preferredX;