isMultiNode property
bool
get
isMultiNode
True if the selection traverses more than one LogicalLine.
Implementation
bool get isMultiNode => nodes.length > 1;
True if the selection traverses more than one LogicalLine.
bool get isMultiNode => nodes.length > 1;