isSingleNode property
bool
get
isSingleNode
True if anchor and focus are on the same container.
Implementation
bool get isSingleNode => nodes.length == 1;
True if anchor and focus are on the same container.
bool get isSingleNode => nodes.length == 1;