SelectedNode class

A node partially or completely traversed by the selection.

Constructors

SelectedNode({required InlineContainerNode container, required Fragment startFragment, required int startOffset, required Fragment endFragment, required int endOffset, required bool isFullySelected})
const

Properties

container InlineContainerNode
The logical container (Paragraph / ListItem / FluentCell).
final
endFragment Fragment
Last selected fragment in this node.
final
endOffset int
Local offset in endFragment where the selection reaches. text.length if the node is completely selected or the selection continues.
final
hashCode int
The hash code for this object.
no setterinherited
isFullySelected bool
True if the entire node is included in the selection (neither startOffset nor endOffset are partial).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startFragment Fragment
First selected fragment in this node. If the node is completely selected, it coincides with the first fragment.
final
startOffset int
Local offset in startFragment where the selection starts. 0 if the node is completely selected or if the selection starts before.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited