endOffset property
Local offset in endFragment where the selection reaches. text.length if the node is completely selected or the selection continues.
Implementation
final int endOffset;
Local offset in endFragment where the selection reaches. text.length if the node is completely selected or the selection continues.
final int endOffset;