isFullySelected property
True if the entire node is included in the selection (neither startOffset nor endOffset are partial).
Implementation
final bool isFullySelected;
True if the entire node is included in the selection (neither startOffset nor endOffset are partial).
final bool isFullySelected;