startFragment property
First selected fragment in this node. If the node is completely selected, it coincides with the first fragment.
Implementation
final Fragment startFragment;
First selected fragment in this node. If the node is completely selected, it coincides with the first fragment.
final Fragment startFragment;