startOffset property
Local offset in startFragment where the selection starts. 0 if the node is completely selected or if the selection starts before.
Implementation
final int startOffset;
Local offset in startFragment where the selection starts. 0 if the node is completely selected or if the selection starts before.
final int startOffset;