FluentFormattingBar class
Reusable formatting bar with all the inline formatting buttons (bold, italic, colors, alignment, lists, etc.). Used by both FluentToolbar (fixed mode) and FluentBubbleToolbar.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FluentFormattingBar
Constructors
-
FluentFormattingBar({Key? key, required FluentDocument document, FluentEditorLabels? labels, bool compact = false, List<
Widget> compactActions = const []}) -
const
Properties
- compact → bool
-
When true, renders buttons in a single horizontal Row (no wrapping).
Intended for the bubble toolbar where vertical space is limited.
final
-
compactActions
→ List<
Widget> -
Extra widgets appended to the end of the compact bar.
Intended for plugin-injected actions like "Add comment".
final
- document → FluentDocument
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labels → FluentEditorLabels?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FluentFormattingBar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited