widgets/nodes/fluent_paragraph_widget library

Classes

FluentParagraphWidget
Paragraph with single TextPainter. The widget is simple: manages only tap and passes cursor offsets to the render object.
FluentParagraphWidgetState<T extends FluentParagraphWidget>
FParagraphRenderWidget
MultiChildRenderObjectWidget that passes cursor/selection offsets to the paragraph and hosts inline widgets (e.g. images inside Link).
InlineImageWidget
Widget for inline images that maintains inline behavior but enables resize