FParagraphRenderWidget class

MultiChildRenderObjectWidget that passes cursor/selection offsets to the paragraph and hosts inline widgets (e.g. images inside Link).

Inheritance

Constructors

FParagraphRenderWidget({Key? key, required InlineContainerNode node, required ParagraphRegistry registry, double lineHeight = 1.15, TextAlign textAlign = TextAlign.left, bool shrinkWrap = false, ParagraphStyle? paragraphStyle, Color? defaultTextColor, Color? cursorColor, Color? selectionColor, Color? linkColor, required String anchorFragmentId, required int anchorLocalOffset, String? focusFragmentId, int? focusLocalOffset, String? selAnchorFragmentId, int? selAnchorLocalOffset, String? selFocusFragmentId, int? selFocusLocalOffset, List<SpellAnnotation> spellAnnotations = const [], List<Map<String, dynamic>> commentAnnotations = const [], String? selectedCommentId, List<Widget> children = const []})
const

Properties

anchorFragmentId String
final
anchorLocalOffset int
final
children List<Widget>
The widgets below this widget in the tree.
finalinherited
commentAnnotations List<Map<String, dynamic>>
final
cursorColor Color?
final
defaultTextColor Color?
final
focusFragmentId String?
final
focusLocalOffset int?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineHeight double
final
linkColor Color?
final
node InlineContainerNode
final
paragraphStyle ParagraphStyle?
final
registry ParagraphRegistry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selAnchorFragmentId String?
final
selAnchorLocalOffset int?
final
selectedCommentId String?
final
selectionColor Color?
final
selFocusFragmentId String?
final
selFocusLocalOffset int?
final
shrinkWrap bool
final
spellAnnotations List<SpellAnnotation>
final
textAlign TextAlign
final

Methods

createElement() MultiChildRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) RenderObject
Creates an instance of the RenderObject class that this RenderObjectWidget represents, using the configuration described by this RenderObjectWidget.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant RenderFluentParagraph renderObject) → void
Copies the configuration described by this RenderObjectWidget to the given RenderObject, which will be of the same type as returned by this object's createRenderObject.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited