onTapDown method
Implementation
void onTapDown(TapDownDetails details) {
// This method is kept for subclass overrides.
// The actual tap logic is handled inline in the GestureDetector within build().
}
void onTapDown(TapDownDetails details) {
// This method is kept for subclass overrides.
// The actual tap logic is handled inline in the GestureDetector within build().
}