FluentTableCellParentData class

Inheritance

Constructors

FluentTableCellParentData()

Properties

col int
getter/setter pair
colSpan int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
nextSibling RenderBox?
The next sibling in the parent's child list.
getter/setter pairinherited
offset Offset
The offset at which to paint the child in the parent's coordinate system.
getter/setter pairinherited
previousSibling RenderBox?
The previous sibling in the parent's child list.
getter/setter pairinherited
row int
getter/setter pair
rowSpan int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
getter/setter pair

Methods

detach() → void
Clear the sibling pointers.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited