imeComposing property
True when an IME composition is active. During composition the cursor is visually locked at imeComposingStart so the user sees a stable insertion point while the preedit text changes.
Implementation
bool imeComposing = false;
True when an IME composition is active. During composition the cursor is visually locked at imeComposingStart so the user sees a stable insertion point while the preedit text changes.
bool imeComposing = false;