FluentCell class
Generic container for table cells. Can contain any type of node (paragraphs, images, tables, etc.) Implements InlineContainerNode for backward compatibility.
- Inheritance
- Implemented types
- Annotations
-
- @JsonSerializable.new()
Constructors
-
FluentCell({List<
FNode> ? children}) -
FluentCell.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
↔ List<
FNode> -
getter/setter pair
- colSpan ↔ int
-
getter/setter pair
- contentVersion → int
-
no setterinherited
-
fragments
→ List<
FNode> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pairinherited
- rowSpan ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Compatibility getter: returns concatenated text from children
no setteroverride
- type → String
-
no setter
Methods
-
bumpVersion(
) → void -
Increment the version so the delta system knows this node changed.
inherited
-
getChildren(
) → List< FNode> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited