Fragment class
- Inheritance
- Implementers
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- color ↔ String?
-
Text color in hex format (e.g. '#FF0000'). Null = auto (default color).
getter/setter pair
- contentVersion → int
-
no setterinherited
- fontFamily ↔ String
-
Font family for this fragment (e.g. 'DejaVu Sans', 'Roboto').
getter/setter pair
- fontSize ↔ double
-
Font size in points (e.g. 14.0).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor ↔ String?
-
Highlight color (background) in hex format. Null = no highlight.
getter/setter pair
- id ↔ String
-
getter/setter pairinherited
- isBold → bool
-
no setter
- renderText → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
↔ List<
String> ? -
List of applied inline styles, e.g.
'bold','italic','bold','italic'.getter/setter pair - text ↔ String
-
getter/setter pair
- type ↔ String
-
getter/setter pair
Methods
-
bumpVersion(
) → void -
Increment the version so the delta system knows this node changed.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited