ArrowKeyRepeater class
Constructors
- ArrowKeyRepeater(ArrowKeyHandler _onRepeat)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether this workaround is active on the current platform.
When false, native KeyRepeatEvent should be handled normally.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
KeyEvent event, {bool fast = false}) → void -
Starts manual repetition for
event. Uses a frame-aligned ticker so repetition never exceeds the display refresh rate and cannot starve the compositor thread. -
stop(
) → void -
supportsRepeat(
LogicalKeyboardKey key) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited