cursorIsAtFragmentStart property
bool
get
cursorIsAtFragmentStart
True when the cursor is at the very start of the current fragment. On buffer-sync platforms (iOS virtual keyboard) the IME has no text before the cursor in its internal buffer, so a backspace will not emit a deletion delta and must be handled structurally by the editor.
Implementation
bool get cursorIsAtFragmentStart => _getCursorOffsetInFragment() == 0;