ImeStateManager class
Constructors
Properties
- composingRange ↔ TextRange
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComposing ↔ bool
-
getter/setter pair
- justCommittedComposition ↔ bool
-
getter/setter pair
- justHandledEnter ↔ bool
-
getter/setter pair
- lastCommittedText ↔ String
-
getter/setter pair
- lastSyncedFragmentId ↔ String
-
getter/setter pair
- lastSyncedText ↔ String
-
getter/setter pair
- preeditCaretOffset ↔ int
-
getter/setter pair
- preeditContainerId ↔ String
-
getter/setter pair
- preeditFragmentId ↔ String
-
getter/setter pair
- preeditLocalOffset ↔ int
-
getter/setter pair
- preeditText ↔ String
-
getter/setter pair
- prevSelectionKey ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleImeText ↔ String?
-
getter/setter pair
- structuralChangeInProgress ↔ bool
-
getter/setter pair
- structuralChangeTimer ↔ Timer?
-
getter/setter pair
- updatingSelf ↔ bool
-
getter/setter pair
Methods
-
attachInput(
) → void -
detachInput(
) → void -
isPreeditInContainer(
String containerId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetComposition(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- structuralChangeGracePeriod → const Duration