DocumentLanguage class
Model for a document language with associated Hunspell dictionary paths.
Constructors
Properties
- code → String
-
final
- flag → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hunspellAff → String
-
final
- hunspellDic → String
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
String code) → DocumentLanguage
Constants
- englishUK → const DocumentLanguage
- englishUS → const DocumentLanguage
- french → const DocumentLanguage
- german → const DocumentLanguage
- italian → const DocumentLanguage
- spanish → const DocumentLanguage
-
supported
→ const List<
DocumentLanguage>