isWrapped property

bool get isWrapped

Returns true if the text was wrapped on multiple lines

Implementation

bool get isWrapped {
  // If the height is significantly greater than the height of one line, it is wrapped
  return size.height > _painter.preferredLineHeight * 1.5;
}