getBoxesForGlobalRange method
Returns the text boxes for a global offset range. Used by the comment plugin to determine the visual position of a comment.
Implementation
List<TextBox> getBoxesForGlobalRange(int start, int end) {
return _painter.getBoxesForSelection(
TextSelection(baseOffset: start, extentOffset: end),
);
}