RenderStyleHook class abstract
Abstract base class for rendering style hooks.
Allows plugins or document settings to hook into the paragraph and node rendering pipeline to dynamically transform text styles (e.g. suggestions, spellcheck errors, comments, custom text highlights).
- Implementers
Constructors
- RenderStyleHook()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appliesTo(
List< String> ? styles, Fragment fragment) → bool -
Returns true if this hook should handle or transform styles for
fragment. -
buildNodeOverlayWidgets(
FNode node, {required BuildContext context, required FluentDocument document}) → List< Widget> - Builds overlay widgets for Widget-rendered nodes (e.g. FluentImage).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveCellBackgroundColor(
FluentCell cell, {BuildContext? context, required FluentDocument document, required bool isResized}) → Color? - Resolves background color for painting FluentCell canvas in tables.
-
resolveHrStyle(
HorizontalRule node, {BuildContext? context, required FluentDocument document, required bool isSelected}) → ({Color? bgTint, Border? border, Color? hrColor})? - Resolves background tint, line color, and border for HorizontalRule.
-
resolveStyle(
TextStyle baseStyle, {required bool isDark, required Fragment fragment, required List< String> styles, required FluentDocument? document}) → TextStyle -
Resolves and returns the transformed TextStyle for
fragment. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited