SpellCheckState class
Holds the current spell-check annotations for the entire document. Organized as a map from nodeId (paragraph id) to a list of annotations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
annotationsForNode(
String nodeId) → List< SpellAnnotation> -
clearAll(
) → void - Clears all annotations.
-
clearNode(
String nodeId) → void -
Removes all annotations for
nodeId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeWord(
String word) → void -
Removes all annotations whose misspelled word equals
word. -
shiftAnnotations(
String nodeId, int fromOffset, int delta) → void -
Shifts all annotations in
nodeIdthat start at or afterfromOffsetbydeltacharacters. Used when the user inserts/deletes text without re-triggering a full spell check. -
toString(
) → String -
A string representation of this object.
inherited
-
updateNode(
String nodeId, List< SpellAnnotation> annotations) → void -
Replaces all annotations for
nodeIdwithannotations.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited