DocumentDelta class sealed
Represents a change to the document at the node level. Deltas are much smaller than full document snapshots because they store only the affected nodes, not the entire tree.
- Implementers
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
apply(
FluentDocument document) → void - Apply this delta (redo). Replaces affected nodes with their post-mutation state and restores the post-mutation cursor.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revert(
FluentDocument document) → void - Revert this delta (undo). Replaces affected nodes with their pre-mutation state and restores the pre-mutation cursor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited