utils/resolve_selection library
Classes
- ResolvedSelection
- The active selection with all references resolved.
- SelectedNode
- A node partially or completely traversed by the selection.
- SelectionEndpoint
- An endpoint of the selection with direct reference to the Fragment.
Functions
-
resolveSelection(
Root root, String anchorFragmentId, int anchorOffset, String focusFragmentId, int focusOffset, {List< CaretStop> ? cachedStops, List<LogicalLine> ? cachedLines}) → ResolvedSelection? -
Resolves the selection defined by (anchorFragmentId, anchorOffset) →
(focusFragmentId, focusOffset) in the
roottree.