ResolvedSelection class
The active selection with all references resolved.
Constructors
-
ResolvedSelection({required SelectionEndpoint anchor, required SelectionEndpoint focus, required SelectionEndpoint base, required SelectionEndpoint extent, required List<
SelectedNode> nodes}) -
const
Properties
- anchor → SelectionEndpoint
-
Fixed endpoint (where the selection started).
final
- base → SelectionEndpoint
-
The endpoint that comes first in the document (anchor or focus).
final
- extent → SelectionEndpoint
-
The endpoint that comes after in the document (anchor or focus).
final
- focus → SelectionEndpoint
-
Mobile endpoint (where the cursor is now).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMultiNode → bool
-
True if the selection traverses more than one LogicalLine.
no setter
- isSingleNode → bool
-
True if anchor and focus are on the same container.
no setter
-
nodes
→ List<
SelectedNode> -
All nodes traversed by the selection, in document order.
The first and last can be partially selected.
Intermediate ones are always completely selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited