SelectionEndpoint class
An endpoint of the selection with direct reference to the Fragment.
Constructors
- SelectionEndpoint({required Fragment fragment, required int offset, required InlineContainerNode container})
-
const
Properties
- container → InlineContainerNode
-
The LogicalLine container (Paragraph / ListItem / FluentCell).
final
- fragment → Fragment
-
The leaf Fragment where this selection endpoint falls.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → int
-
Local offset inside fragment.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited