widgets/editor/fluent_positioned_sidebar library
Classes
- FluentPositionedSidebar
- Generic sidebar widget that positions FluentSidebarItem cards vertically at the Y coordinate of their target document node, resolving collisions and scrolling in 1-to-1 sync with the document.
- FluentSidebarItem
- A generic item entry for the positioned sidebar.
Enums
- FluentSidebarItemCategory
- Categories for items displayed in the sidebar.