FluentSidebarItem class
A generic item entry for the positioned sidebar.
Constructors
- FluentSidebarItem({required String id, required String nodeId, CaretStop? stop, required Widget widget, double estimatedHeight = 130.0, DateTime? createdAt, FluentSidebarItemCategory category = FluentSidebarItemCategory.other})
-
const
Properties
- category → FluentSidebarItemCategory
-
final
- createdAt → DateTime?
-
final
- estimatedHeight → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- nodeId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stop → CaretStop?
-
final
- widget → Widget
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited