widgets/nodes/fluent_link_widget library
Classes
- FluentLinkWidget
- DEPRECATED: With the new architecture, Links are managed as TextSpan inside RenderFluentParagraph. This widget returns an empty widget because the link is already rendered by the parent paragraph.